@@ -15,5 +15,8 @@
      *	Es /19.3d-3/,                 ! scattering const. Note, not 21 MeV.
      *  Knockon /.true./,            ! knockon is considered. Obsolete
      *  PhotoProd /.false./,        ! gp--> hadrons not considered.
+     *  Excom1 /1.0d-3/,                ! if Eg <=Excom1,  XCOM data is used for 
+                                    ! compton/p.e/coherent .
+     *  Excom1 /1.0d-3/,                ! if Eg <= Excom2, XCOM data for Pair cre.
      *  Moliere /2/                 ! Moliere scattering for non-electron 
 	end
