@@ -61,11 +61,10 @@ c     integer ndummy
       character*128 title
       character*96 evid(nsites)
       save evid
-      real*8 cog, cog2, sumne,  obstimes, Savederg(5)
-      real*8 depth
+      real*8 cog, sumne,  obstimes, Savederg(5)
       logical dosort
       character*2  kd(3)
-      save obstimes,  depth
+      save obstimes
 
 c       keep this interface so that the difference between
 c       the one in ForTA/  and in FleshHist is in the next line
@@ -390,20 +389,17 @@ c     *  eneded at this moment.
 c     *  After this is executed, event generation starts.
 c     *
       entry xBgEvent
+
+
       call cqIncident(inci, angle)
-
-       write(*,'("i ",  i3,  i4, g13.4,3f11.7,f7.1)')
-     *    EventNo, inci.p.code,
-     *   inci.p.fm.e,  -angle.r(1),  -angle.r(2), -angle.r(3)
-
-
-
+      write(*,'("i ",  i3,  i4, g13.4,3f11.7)') EventNo, inci.p.code,
+     *   inci.p.fm.e,  -angle.r(1),  -angle.r(2), -angle.r(3)      
+c      
       do i = 1, NoOfASSites
          SumEloss(i) = 0.
          Ng(i) = 0.
          Ne(i) = 0.
          Nmu(i) = 0.
-         Nhad(i) = 0.
       enddo
 
       if(tklat) then
@@ -527,8 +523,6 @@ c     For id =2, you need not output the z value, because it is always
 c     0 (within the computational accuracy).
 c
 c     **************************
-
-
       obstimes = obstimes + 1.d0
       if(mod(obstimes, 100000.d0) .eq. 0. ) then 
          dosort=.false.
@@ -565,8 +559,6 @@ c     ***************
             Ne(ldep) = Ne(ldep) + aTrack.wgt
          elseif(code .eq. kmuon) then
             Nmu(ldep) = Nmu(ldep) + aTrack.wgt
-         elseif(code .le. 6) then
-            Nhad(ldep) = Nhad(ldep) +aTrack.wgt
          endif
 
          do i = 1, ansites
@@ -627,7 +619,7 @@ c                     see if this is > K.E
                Eloss = Ek
                dist = Eloss/dedt
             endif
-            Eloss = Eloss*aTrack.wgt       !  GeV/(g/cm2)
+            Eloss = Eloss*10.       !  GeV/(g/cm2)
             SumEloss(ldep)=SumEloss(ldep) + Eloss
          endif
       endif
@@ -787,8 +779,6 @@ c                  re spectrum
 c     **************
       entry xEnEvent
 c     **************
-      call cqFirstID(depth)
-      depth = depth* 0.1     ! in g/cm2  First col depth.
 
       if(ObserveAS) then
          cog = 0.
@@ -799,55 +789,25 @@ c     **************
          enddo
          cog = cog/sumne
 
-         cog2 = 0.
-         sumne = 0.
-         do i = 1, NoOfASSites
-            if( ASObsSites(i).age .gt.
-     *          (2.0-ASObsSites(NoOfASSites).age))  then
-               cog2 = cog2 + ASObsSites(i).esize*ASDepthList(i)*0.1
-               sumne= sumne +ASObsSites(i).esize
-            endif
-         enddo
-         if(sumne .gt. 0.) then
-            cog2 = cog2/sumne
-         else
-c              too deep penetrate
-            cog2 = ASDepthList(NoOfASSites)*0.1
-         endif
-
-
-         if(fnoB .ge. 0 )  then
-            write(fnoB,
-     *      '("h ", i4,  3i3, 1pE11.3, 0p 3f11.7, f7.2, 2f7.0)')
-     *      EventNo,  inci.p.code,
-     *      inci.p.subcode, inci.p.charge,
-     *      inci.p.fm.e, -angle.r(1), -angle.r(2), -angle.r(3),
-     *      depth, cog, cog2
-         else
-            write(*,
-     *      '("h ", i4,  3i3, 1pE11.3, 0p 3f11.7, f7.2, 2f7.0)')
-     *      EventNo,  inci.p.code,
-     *      inci.p.subcode, inci.p.charge,
-     *      inci.p.fm.e, -angle.r(1), -angle.r(2), -angle.r(3),
-     *      depth, cog, cog2
-         endif
          do i = 1, NoOfASSites 
             if(fnoB .ge. 0) then
-               write(fnoB, '("t ", i3, 2f7.1,  2f6.3,
-     *         1p6E11.3)')
-     *          i, 
-     *          ASDepthList(i)*0.1,  ASObsSites(i).mu,
-     *          ASObsSites(i).age,   ASDepthList(i)*0.1/cog2, 
-     *          Ng(i), Ne(i), Nmu(i), Nhad(i),
-     *          ASObsSites(i).esize, SumEloss(i)  
+               write(fnoB, '( i4, i3, i5,
+     *          1pE11.3, 0pf5.2, f5.2, 1pE11.3, 0pf7.1,
+     *          1p3E11.3, 0pf7.0)')
+     *          EventNo, i,
+     *          int( ASDepthList(i)*0.1 ),  
+     *          sngl(ASObsSites(i).esize), sngl(ASObsSites(i).age),
+     *          ASDepthList(i)*0.1/cog, SumEloss(i),  
+     *          sngl(ASObsSites(i).mu), Ng(i), Ne(i), Nmu(i), cog
             else
-               write(*, '("t ", i3, 2f7.1,  2f6.3,
-     *         1p6E11.3)')
-     *          i, 
-     *          ASDepthList(i)*0.1,  ASObsSites(i).mu,
-     *          ASObsSites(i).age,   ASDepthList(i)*0.1/cog2, 
-     *          Ng(i), Ne(i), Nmu(i), Nhad(i),
-     *          ASObsSites(i).esize, SumEloss(i)  
+               write(*, '( i4, i3, i5,
+     *          1pE11.3, 0pf5.2, f5.2, 1pE11.3, 0pf7.1,
+     *          1p3E11.3, 0pf7.0)')
+     *          EventNo, i,
+     *          int( ASDepthList(i)*0.1 ),  
+     *          sngl(ASObsSites(i).esize), sngl(ASObsSites(i).age),
+     *          ASDepthList(i)*0.1/cog, SumEloss(i),  
+     *          sngl(ASObsSites(i).mu), Ng(i), Ne(i), Nmu(i), cog
             endif
          enddo
       endif
@@ -863,8 +823,8 @@ c              too deep penetrate
      *   '(i3, i5,  f5.2, f5.2,
      *   i5,  i4)')
      *   histdep(i), int( ASDepthList(j)*0.1 ),  
-     *   ASObsSites(j).age, ASDepthList(j)*0.1/cog2,
-     *   int(ASObsSites(j).mu), int(cog2)
+     *   ASObsSites(j).age, ASDepthList(j)*0.1/cog,
+     *   int(ASObsSites(j).mu), int(cog)
       enddo
 
 
