@@ -10,9 +10,11 @@ c
       elseif(IntInfArray(ProcessNo).process .eq. 'compt') then
          call ccompt
       elseif(IntInfArray(ProcessNo).process .eq. 'photoe') then
-c         call cphtoEE  ! at present,  neglected  ********************
+         call cphotoEE  
       elseif(IntInfArray(ProcessNo).process .eq. 'photop') then
          call cphotop
+      elseif(IntInfArray(ProcessNo).process .eq. 'cohs') then
+         call ccohs
       elseif(IntInfArray(ProcessNo).process .eq. 'mpair') then
          call cmpair
       else
@@ -58,6 +60,8 @@ c          store higher energy ptcl later
          e1= e2
          e2 = temp
       endif
+c         now e1 < e2
+      
 c            assign charge for e1
       call rndc(u)
       if(u .gt. .5) then
@@ -67,30 +71,48 @@ c            assign charge for e1
       endif
 c     
       aTrack = MovedTrack
-      if(eg .lt. 100.e-3) then
-c          take pair angle if < 100 MeV
-         call kcossn(cs, sn)
+c      if(eg .lt. 100.e-3) then
+c          take  pair angle if < 100 MeV
+      if(eg .lt. 10) then
+c          take  pair angle if < 10GeV
+          call cPairAng(e1, masele, teta1) ! teta1 < pi/2
+          if(teta1 .lt. 0.03d0) then
+             cos1 = 1. - teta1**2/2
+             sin1 = teta1
+          else
+             cos1 = cos(teta1)
+             sin1 = sin(teta1)
+          endif
+c
+          sin2 = sin1 * sqrt(  (e1**2-masele**2)/(e2**2-masele**2) )
+          if(sin2 .lt. 0.03d0) then
+             cos2 = 1.- sin2**2/2
+          else
+             cos2 = sqrt(1.d0 - sin2**2)
+          endif
+          call kcossn(cs, sn)
 
-         teta = masele/eg
-         teta1=teta* e2/eg
-         teta2=teta* e1/eg
-         cos1=1. - teta1**2/2
-         cos2=1. - teta2**2/2
+c         teta = masele/eg
+c         teta1=teta* e2/eg
+c         teta2=teta* e1/eg
+c         cos1=1. - teta1**2/2
+c         cos2=1. - teta2**2/2
 c               sample direction cos. of 1st
-         sin1=teta1
+c         sin1=teta1
+c         sin2=teta2
+c
          dc.r(1) = cs * sin1
          dc.r(2) = sn * sin1
          dc.r(3)=  cos1
          call ctransVectZ(MovedTrack.vec.w, dc, dce)
-
          call cmkptc(kelec, 0, ica, aTrack.p)
          aTrack.p.fm.p(4) = e1
          call csetDirCos(dce, aTrack)
          call ce2p(aTrack)
          Nproduced = Nproduced + 1
          Pwork(Nproduced) = aTrack.p
-c            another electron
-         sin2=teta2
+c            another electron (higher E)
+
          dc.r(1) = -cs*sin2
          dc.r(2) = -sn*sin2
          dc.r(3) = cos2
@@ -188,6 +210,83 @@ c         aTrack.p = Pwork(i)
 c         call cpush(aTrack)
 c      enddo
       end
+c     ****************
+      subroutine ccohs
+c     ****************
+c        coherent scattering
+      implicit none
+#include  "Zcode.h"
+#include  "Ztrack.h"
+#include  "Ztrackv.h"
+c     ******************
+c        since coherent scattering is effective at
+c        low energies where angular distribution can be
+c        approximated by (1+cos^2) dcos, we simply use
+   
+      record /track/aTrack
+      record /coord/ w
+      real*8 cosg, tmp, cs, sn, sing
+c             sample scattering angle from (1+cos^2)dcos
+      call ksampRSA(cosg)
+      tmp=1.d0-cosg*cosg
+      sing = sqrt(tmp)
+      call kcossn(cs,sn)
+      
+      w.r(1) = cs*sing
+      w.r(2) = sn*sing
+      w.r(2) = cosg
+      call ctransVectZ(MovedTrack.vec.w,  w, w)
+c        energy unchaged;
+      call csetDirCos(w, aTrack)
+      call ce2p(aTrack)
+      Nproduced = Nproduced + 1
+      Pwork(Nproduced) = aTrack.p
+      end
+c     ****************
+      subroutine cphotoEE
+c     ****************
+c        photo electric effect
+      implicit none
+#include  "Zcode.h"
+#include  "Zmass.h"
+#include  "Ztrack.h"
+#include  "Ztrackv.h"
+c     ******************
+      record /track/aTrack
+      record /coord/ w
+      real*8  cs, sn, sing
+
+      real*8 eout, eg, rEg, rEe, cost, a, tmp
+c          essentially no shell down to 1keV.
+      eg = MovedTrack.p.fm.p(4)
+      eout = masele + eg
+      
+      aTrack = MovedTrack
+      rEg=eg/masele
+      rEe=(eout-masele) /masele
+      if(rEe .le. 0.) then
+         cost=1.
+      else
+         a = ( TargetAtomicN/137.0/137.0 + 2.0*rEe + rEg**2 )/
+     *    (2.0*rEg*sqrt(2.0*rEe) )
+         call ksampPEang(a, cost)
+      endif
+      
+      tmp=1.d0-cost*cost
+      sing = sqrt(tmp)
+      call kcossn(cs,sn)
+      
+      w.r(1) = cs*sing
+      w.r(2) = sn*sing
+      w.r(2) = cost
+      call ctransVectZ(MovedTrack.vec.w,  w, w)
+      aTrack.p.fm.p(4) = eout
+      call cmkptc(kelec, 0, -1, aTrack.p)
+      call csetDirCos(w, aTrack)
+      call ce2p(aTrack)
+      Nproduced = Nproduced + 1
+      Pwork(Nproduced) = aTrack.p
+      end
 c     *******************
       subroutine cmpair
 c         magnetic pair creation
