@@ -9,7 +9,6 @@ c
 #include  "Ztrackp.h"
 #include  "Ztrackv.h"
 #include  "Zincidentv.h"
-c
 
 c
 c          used to judge if user hook should be called 
@@ -18,14 +17,11 @@ c
       integer neverNEP/0/,  neverE/0/,  neverG/0/
       save  neverNEP, neverE, neverG
       integer never
+      integer stackpos
       save never
-c/////////////
-c      logical deb
-c      common /cccdeb/ deb
-c//////////
 
-      record /ptcl/ fragA(maxHeavyMassN),  nonIntNucA(maxHeavyMassN)
-      integer noOfFrag, noOfNonIntN
+cc      record /ptcl/ fragA(maxHeavyMassN),  nonIntNucA(maxHeavyMassN)
+cc      integer noOfFrag, noOfNonIntN
 c
 c      record /track/aTrack
 c
@@ -34,12 +30,6 @@ c           (except for hadronic interactions)
 
       Nproduced = 0
 
-c//////////////
-c         if( deb ) then
-c            write(*,*) ' top of  cinteraction '
-c         endif
-c////////////////
-c
 
 c
 cc    assume MovedTrack is not changed in interaction routine
@@ -49,87 +39,82 @@ c
 c
       if(MovedTrack.p.code .eq. kelec) then
          call cinteElec
+      elseif(MovedTrack.p.code .eq. kphoton) then
+          call cintePhoton
+      else
+          call cinteNEP
+          if(IntInfArray(ProcessNo).process .eq. 'coll') then
+             MovedTrack.pos.colheight = MovedTrack.pos.height
+          endif
+      endif
+
+      if(OneDim .eq. 0) then
+c            3 dimensional
+c                 stack the leading ptcl  first (to save stack area)
+         call cmovePtcl3(MovedTrack, Pwork, Nproduced, Nstacked)
+      else
+         MovedTrack.vec = IncidentCopy.vec
+         call cmovePtcl1(MovedTrack, Pwork, Nproduced, Nstacked)
+      endif
+      if(MovedTrack.p.code .eq. kelec) then
          if(neverE .ne. 1) then
             call chookEInt(neverE)
             never = neverE
          endif
-
       elseif(MovedTrack.p.code .eq. kphoton) then
-
-          call cintePhoton
           if(neverG  .ne. 1)  then
              call chookGInt(neverG)
              never = neverG
           endif
-
       else
-          call cinteNEP
-c//////////////
-c         if( deb ) then
-c            write(*,*) ' aftere cinteNEP '
-c         endif
-c////////////////
-
-          if(IntInfArray(ProcessNo).process .eq. 'coll') then
-             MovedTrack.pos.colheight = MovedTrack.pos.height
-          endif
-c             interface with user hook  ***********************
-          if(neverNEP .ne. 1) then
-             call chookNEPInt(neverNEP)
-c//////////////
-c         if( deb ) then
-c            write(*,*) ' after chookNEPint '
-c         endif
-c////////////////
-
-             never = neverNEP
-          endif
-c             *******************************
-      endif
-
-      if( never .eq. 1 .or. never .eq. 0) then
-         if(OneDim .eq. 0) then
-c            3 dimensional
-c                 stack the leading ptcl  first (to save stack area)
-            call cmovePtcl3(MovedTrack, Pwork, Nproduced)
-         else
-            MovedTrack.vec = IncidentCopy.vec
-            call cmovePtcl1(MovedTrack, Pwork, Nproduced)
+         if(neverNEP .ne. 1) then
+            call chookNEPInt(neverNEP)
+            never = neverNEP
          endif
-      elseif(never .eq. 2) then
-c              save only fragments and non interacting nucleons
-cc         if(MovedTrack.p.code .ge. kdeut .and. 
-cc     *      MovedTrack.p.code .le. khvymax ) then
-         if(MovedTrack.p.code .eq. kgnuc ) then
-c               get fragment and non interacting nuc.
-            call cqHvyIntF(fragA, noOfFrag)
-            call cqHvyIntNIN(nonIntNucA, noOfNonIntN)
-
-            if(OneDim .eq. 0) then
-                call cmovePtcl3(MovedTrack, fragA, noOfFrag)
-                call cmovePtcl3(MovedTrack, nonIntNucA, noOfNonIntN)
-             else
-                MovedTrack.vec = IncidentCopy.vec
-                call cmovePtcl1(MovedTrack, fragA, noOfFrag)
-                call cmovePtcl1(MovedTrack, nonIntNucA, noOfNonIntN)
-             endif
-          endif
+      endif
+      if(never .eq. 0 .or. never .eq. 1 ) then
+c          user may set never=3 
       elseif(never .eq. 3) then
-c              don't follow all this child
+c          don't follow this and  child; reset stackpos
+         call cgetCurrentStackpos(stackpos)
+         stackpos=stackpos-Nstacked
+         call cresetStackpos(stackpos)
       elseif(never .eq. 4) then
 c             discard this event
 c             clear stack
          call cinitStack
       else
          call cerrorMsg('return value from chookE,G,NEPInt wrong', 0)
+         write(0,*)  ' never=', never
       endif
       end
+c          following is remnant of never=2 and ad-hoc model
+c          when chookNEPInt is called before push is called.
+c      elseif(never .eq. 2) then
+c              save only fragments and non interacting nucleons
+c         if(MovedTrack.p.code .eq. kgnuc ) then
+cc               get fragment and non interacting nuc.
+c            call cqHvyIntF(fragA, noOfFrag)
+c            call cqHvyIntNIN(nonIntNucA, noOfNonIntN)
+cc
+c            if(OneDim .eq. 0) then
+c                call cmovePtcl3(MovedTrack, fragA, noOfFrag)
+c                call cmovePtcl3(MovedTrack, nonIntNucA, noOfNonIntN)
+c             else
+c                MovedTrack.vec = IncidentCopy.vec
+c                call cmovePtcl1(MovedTrack, fragA, noOfFrag)
+c                call cmovePtcl1(MovedTrack, nonIntNucA, noOfNonIntN)
+c             endif
+c          endif
+c
 c     ************************************
 c          move partcles in a given array to stack
 c          3 dimensional case.
 
-      subroutine  cmovePtcl3(iTrack, pw, n)
+      subroutine  cmovePtcl3(iTrack, pw, n, npush)
       implicit none
+c                put n ptcls in pw into stack.
+c          if ThinSampling, 
 #include  "Zcode.h"
 #include  "Ztrackp.h"
 #include  "Ztrack.h"
@@ -138,15 +123,16 @@ c
       integer n
       record /track/ iTrack  ! input. incident ptcl.
       record /ptcl/ pw(n)
-      logical needThin
+      integer npush   ! output. actual number of ptcls put in stack.
+                   ! in case of ThinSampling, this may be <= Nproduced. 
 
       record /track/ aTrack  
       integer i, icon
       
-c      needThin= ThinSampling .and. iTrack.p.fm.p(4) .lt. Ethin(1)
+
 
       aTrack = iTrack
-
+      npush = 0
       do i =  n, 1, -1          ! move leading ptcl first
 #ifdef SUBSTREC
          aTrack.p = pw(i)
@@ -160,9 +146,6 @@ c      needThin= ThinSampling .and. iTrack.p.fm.p(4) .lt. Ethin(1)
 
 c               reset direction cos and related stuffs
          call cresetDirec(aTrack)
-
-
-c         if(needThin) then
          if(ThinSampling) then
             call csetThinwgt(iTrack, aTrack,  icon)
          else
@@ -188,6 +171,7 @@ c
             call ctrickycount(iTrack, aTrack, pw, i)
 c
 #endif
+            npush = npush + 1
             call cpush(aTrack)
          endif
       enddo 
@@ -264,7 +248,7 @@ c     ************************************
 c          move partcles in a given array to stack
 c          1 dimensional case.
 
-      subroutine  cmovePtcl1(iTrack, pw, n)
+      subroutine  cmovePtcl1(iTrack, pw, n, npush)
       implicit none
 
 #include  "Zcode.h"
@@ -277,13 +261,14 @@ c          1 dimensional case.
       integer n
       record /track/ iTrack   ! input. incident track
       record /ptcl/ pw(n)
+      integer  npush   !  output.  actuall number of ptcls put in stack.
       real*8 temp, p
-      logical needThin
+
       integer i, icon
       
       record /track/ aTrack 
 
-c      needThin =ThinSampling .and. iTrack.p.fm.p(4) .lt. Ethin(1)
+
 
       aTrack = iTrack
 
@@ -314,7 +299,7 @@ c            call cresetMom(aTrack)  which is
 
             call cgetZenith(aTrack, aTrack.vec.coszenith)
 
-c            if(needThin) then
+
             if(ThinSampling) then
                call csetThinwgt(iTrack, aTrack, icon)
             else
@@ -338,6 +323,7 @@ c                   this may be used if a tricky count is needed
 c               in stead of above  counting
                call ctrickycount(iTrack, aTrack, pw, i)
 #endif
+               npush = npush + 1  
                call cpush(aTrack)
             endif
          endif
@@ -383,47 +369,115 @@ cc     *    MovedTrack.p.code .le. khvymax ) then
 c     ***************************
       subroutine csetThinwgt(iTrack, aTrack, icon)
       implicit none
+#include  "Zcode.h"
 #include  "Ztrack.h"
+#include  "Ztrackp.h"
 #include  "Ztrackv.h"
-      record /track/ iTrack   ! input   particle
-      record /track/ aTrack  ! input/output.    particle
+#include  "Zincidentv.h"
+#include  "Zelemagp.h"
+
+      record /track/ iTrack   ! input  parent particle
+      record /track/ aTrack  ! input   child particle
+c                            ! output.    wgt
       integer icon           ! output.  0 if this is not tobe discarded
                              !          1 if this is to be discarded
       real*8 u, p 
+      real*8 iergpn, aergpn
+      logical dothin
+      real*8 dd, rhoE
+      real*8 cvh2den
+      real*8 Z1, E0
+      data Z1/-1./, E0/-1./
+      save Z1, E0, rhoE, dd
 
-      if(iTrack.p.fm.p(4) .gt. Ethin(1) ) then
-         if(aTrack.p.fm.p(4) .gt. Ethin(1)) then
-            p = 1.
-            icon = 0
-         elseif(aTrack.p.fm.p(4) .gt. Ethin(2)) then
-            p = aTrack.p.fm.p(4)/Ethin(1)
+      if(IncidentCopy.p.code .eq. kphoton  .and.
+     *    PhotoProd )  then
+c            photon  primary and muon is interested
+c            so thinsamling must be carfull
+c            we apply thinning only if current depth is
+c            > 120 g/cm2 from the first col. point.
+         if(Z1 .ne.  Zfirst.pos.depth  .or.
+     *      E0 .ne.  IncidentCopy.p.fm.p(4) ) then
+            Z1 = Zfirst.pos.depth 
+            E0 = IncidentCopy.p.fm.p(4) 
+            if( LpmEffect ) then
+               rhoE=cvh2den( Zfirst.pos.height )* 1.e-3 * 
+     *             IncidentCopy.p.fm.p(4) 
+               if(rhoE .lt. 1.e6)  then
+                  dd = 200.
+               else
+                  dd =min( 200.* sqrt(rhoE/1.e6), 1000.d0)
+               endif
+            else
+               dd = 200.
+            endif
+         endif
+
+         if(  MagBrem .eq. 2 .and.   Z1 .lt. 1.e-6 ) then
+            dothin = iTrack.pos.depth/Zfirst.vec.coszenith
+     *           .gt. 300.
+         else
+            dothin=( iTrack.pos.depth-Zfirst.pos.depth)/
+     *           Zfirst.vec.coszenith .gt. (1000.+ dd)
+         endif
+      else
+         dothin = .true.
+      endif
+      if(dothin) then 
+         iergpn = iTrack.p.fm.p(4)
+         if(iTrack.p.code .eq. kgnuc) then
+            iergpn = iergpn/ iTrack.p.subcode
+         endif
+         aergpn = aTrack.p.fm.p(4)
+         if(aTrack.p.code .eq. kgnuc) then
+            aergpn = aergpn / aTrack.p.subcode
+         endif
+c        We apply thinning if Ethin1>  E
+c        and weight is < Ethin2 
+c           Weight and energy has
+c           E=Ethin(1)/w ; at very low energies
+c          (say < 1GeV ), E<=Ethin(1)/w begins
+c           and brodens  
+         if(iergpn .gt. Ethin(1) ) then
+            if(aergpn .gt. Ethin(1)) then
+c                    Both   Ei, Ec> Ethin1; no thinning
+               icon = 0
+               aTrack.wgt = iTrack.wgt
+c         elseif(aergpn .gt. Ethin(2)) then 
+            elseif( aTrack.wgt .lt. Ethin(2)) then
+c              
+               p = aergpn/Ethin(1)
+               call rndc(u)
+               if(u .lt. p)  then
+                  icon = 0
+                  aTrack.wgt = iTrack.wgt / p
+               else
+                  icon = 1
+               endif
+            else
+               icon = 0
+               aTrack.wgt = iTrack.wgt 
+            endif
+c      elseif(iergpn .gt. Ethin(2) .and.
+c     *       aergpn .gt. Ethin(2) ) then
+         elseif(iTrack.wgt .lt. Ethin(2) .and.
+     *           aTrack.wgt .lt. Ethin(2) ) then
+            p = aergpn/iergpn
             call rndc(u)
-            if(u .lt. p)  then
+            if(u .lt. p ) then
                icon = 0
                aTrack.wgt = iTrack.wgt / p
             else
                icon = 1
             endif
          else
-c               keep the wgt as it is 
-            icon = 0
+            icon =0
             aTrack.wgt = iTrack.wgt
          endif
-      elseif(iTrack.p.fm.p(4) .gt. Ethin(2) ) then
-         p = aTrack.p.fm.p(4)/iTrack.p.fm.p(4) 
-         call rndc(u)
-         if(u .lt. p ) then
-            icon = 0
-            aTrack.wgt = iTrack.wgt / p
-         else
-            icon = 1
-         endif
       else
-         icon =0
+         icon = 0
          aTrack.wgt = iTrack.wgt
       endif
       end
 
 
-
-
