@@ -12,14 +12,30 @@ c  the resultant data can be drawn by, say, gnuplot.
          real*8 year, lat, long, h
          record /coord/ llh
          record /magfield/ b, hva
-         integer icon, ilat, ilong
+         integer icon, ilat, ilong, igrf
+         character*64 file
 c
          year=2000.
+         h =0.
          call cerrorMsg(
-     *   'Enter year of geomagnetism (=2000)', 1)
-         read(*,*) year
+     *   'Enter year of geomagnetism (=2000) and height(=0 m)', 
+     *    1)
+         read(*,*) year, h
 
-         h  = 0.d0
+         call cerrorMsg(
+     *   'Enter 1, 2 or 3 for 1) igrf, 2) wmm or other data', 1)
+         read(*,*) igrf
+
+         if(igrf .eq. 1) then
+            file = '../Data/Geomag/igrf'
+         elseif(igrf .eq. 2) then
+            file = '../Data/Geomag/wmm'
+         else
+            call cerrorMsg('Enter file path for geomag data',1)
+            read(*,*) file
+         endif
+
+         call crdGeomag(file, year)
          write(*,'("#     lat   long   H   V (Tesla) Ang(deg) ")')
          do ilat = -90, 90,  5
             lat = ilat
