@@ -10,10 +10,4 @@ c          testing creadParm
       call creadParam(5)
       call cwriteParam(ErrorOut, 1)
       end
-#include "BlockData/cblkEvhnp.h"
-#include "BlockData/cblkHeavy.h"
-#include "BlockData/cblkIncident.h"
-#include "BlockData/cblkElemag.h"
-#include "BlockData/cblkObs.h"
-#include "BlockData/cblkTracking.h"
-#include "BlockData/cblkXsec.h"
+#include "BlockData/cblkGene.h"
